
# Slot: subject


the molecular entity that is an interactor

URI: [biolink:molecular_entity_to_entity_association_mixin_subject](https://w3id.org/biolink/vocab/molecular_entity_to_entity_association_mixin_subject)


## Domain and Range

[MolecularEntityToEntityAssociationMixin](MolecularEntityToEntityAssociationMixin.md) &#8594;  <sub>1..1</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [subject](subject.md)

## Children

 *  [chemical to entity association mixin➞subject](chemical_to_entity_association_mixin_subject.md)
 *  [drug to entity association mixin➞subject](drug_to_entity_association_mixin_subject.md)

## Used by

 * [MolecularEntityToEntityAssociationMixin](MolecularEntityToEntityAssociationMixin.md)
